[igt-dev] [PATCH i-g-t] tests/kms_flip: Restrict the hang tests execution to first and last pipe combinations

Jeevan B jeevan.b at intel.com
Tue Jul 18 11:00:06 UTC 2023


restrict the hang tests execution to single pipe combinations still
causing timed-out so limiting the combination to first and last pipe.

Signed-off-by: Jeevan B <jeevan.b at intel.com>
---
 tests/kms_flip.c | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/tests/kms_flip.c b/tests/kms_flip.c
index ef2234f74..ee4e8a43d 100755
--- a/tests/kms_flip.c
+++ b/tests/kms_flip.c
@@ -1729,10 +1729,14 @@ static void run_pair(int duration, int flags)
 					crtc_idxs[0] = n;
 					crtc_idxs[1] = m;
 
 					/* Limit the execution to PIPE_A combination for hang tests */
 					if ((flags & TEST_HANG) && !all_pipes &&
 					    (n != 0 && n != resources->count_crtcs))
 						continue;
+					if ((flags & TEST_HANG) && !all_pipes &&
+					    m != resources->count_crtcs - 1)
+						continue;
 
 					run_test_on_crtc_set(&o, crtc_idxs,
 							     RUN_PAIR,
@@ -1729,10 +1729,14 @@ static void run_pair(int duration, int flags)
 					crtc_idxs[1] = m;
 
-					/* Limit the execution to PIPE_A combination for hang tests */
+					/* Limit the execution to 2 CRTCs
+					 * (first and last combination) for hang tests */
 					if ((flags & TEST_HANG) && !all_pipes &&
 					    (n != 0 && n != resources->count_crtcs))
-- 
2.41.0



More information about the igt-dev mailing list